@@ -57,7 +57,7 @@ program t_cmor_fx_basin
   error_flag = cmor_dataset_json("Test/CMOR_input_example.json")
 
   if (error_flag.ne.0) then
-    write(6,*)"Error in cmor_dataset: ",error_flag
+    write(6,*)"Error in cmor_dataset_json: ",error_flag
     stop
   endif
 
