@@ -1,7 +1,8 @@
-import cdms2
+from __future__ import print_function
 import cmor
 import numpy
 import os
+import sys
 import common
 
 varin3d = ["MC", ]
@@ -20,20 +21,20 @@ print("ILEVL half:", ilev_half)
 
 cmor.zfactor(zaxis_id=ilev_half, zfactor_name='p0',
              units='hPa', zfactor_values=common.p0)
-print "p0 1/2"
+print("p0 1/2")
 cmor.zfactor(zaxis_id=ilev_half, zfactor_name='b_half', axis_ids=[ilev_half, ],
              zfactor_values=common.b_coeff)
-print "b 1/2"
+print("b 1/2")
 cmor.zfactor(zaxis_id=ilev_half, zfactor_name='a_half', axis_ids=[ilev_half, ],
              zfactor_values=common.a_coeff)
-print "a 1/2"
+print("a 1/2")
 ps_var = cmor.zfactor(zaxis_id=ilev_half, zfactor_name='ps',
                       axis_ids=[ilon, ilat, itim], units='hPa')
-print "ps 1/2"
+print("ps 1/2")
 
 var3d_ids = []
 for m in varin3d:
-    print "3d VAR:", m
+    print("3d VAR:", m)
     var3d_ids.append(
         cmor.variable(table_entry=common.specs[m]["entry"],
                       units=common.specs[m]["units"],
@@ -42,14 +43,14 @@ for m in varin3d:
                       positive=common.specs[m]["positive"],
                       original_name=m)
     )
-print "Ok now writing", var3d_ids, common.ntimes
+print("Ok now writing", var3d_ids, common.ntimes)
 for index in range(common.ntimes):
     tim_array, bnds_tim = common.read_time(index)
     for i, varname in enumerate(varin3d):
         data = common.read_3d_input_files(
             index, varname, (common.lev, common.lat, common.lon))
-        print data.shape, data
-        print tim_array, bnds_tim
+        print(data.shape, data)
+        print(tim_array, bnds_tim)
         cmor.write(var_id=var3d_ids[i], data=data, ntimes_passed=1,
                    time_vals=tim_array, time_bnds=bnds_tim)
         print("Passed write")
