@@ -263,10 +263,10 @@ int main()
     strcpy(c2, "Nat, TO");
 
     printf("yep: %s, %s\n", c1, c2);
-    ierr = cmor_dataset_json("Test/CMOR_input_example.json");
+    ierr = cmor_dataset_json("Test/CMOR_input_TestTables.json");
 
     printf("Test code: ok load cmor table(s)\n");
-    ierr = cmor_load_table("Tables/CMIP6_Amon_json_hfls", &tables[0]);
+    ierr = cmor_load_table("TestTables/CMIP6_Amon_json_hfls", &tables[0]);
     strcpy(id, "time");
     strcpy(units, "months since 1980");
     strcpy(interval, "1 month");
