@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import print_function
 import cmor
 import numpy
 
@@ -32,12 +33,12 @@ def main():
 
     axis_ids = list()
     for axis in axes:
-        print 'doing:', axis
+        print('doing:', axis)
         axis_id = cmor.axis(**axis)
         axis_ids.append(axis_id)
 
     for var, units, value in (('difvso', 'm2 s-1', 274.),):
-        values = numpy.ones(map(lambda x: len(x["coord_vals"]), axes)) * value
+        values = numpy.ones([len(x["coord_vals"]) for x in axes]) * value
         values = values.astype("f")
         varid = cmor.variable(var,
                               units,
