@@ -2,7 +2,7 @@
 #define CMOR_H
 
 #define CMOR_VERSION_MAJOR 3
-#define CMOR_VERSION_MINOR 5
+#define CMOR_VERSION_MINOR 6
 #define CMOR_VERSION_PATCH 0
 
 #define CMOR_CF_VERSION_MAJOR 1
@@ -188,7 +188,7 @@
 #define GLOBAL_ATT_TITLE_MSG          "%s output prepared for %s"
 #define GLOBAL_ATT_EXTERNAL_VAR       "external_variables"
 #define GLOBAL_ATT_MIP_ERA            "mip_era"
-#define GLOBAL_CV_FILENAME            GLOBAL_INTERNAL"control_vocabulary_file"
+#define GLOBAL_CV_FILENAME            GLOBAL_INTERNAL"controlled_vocabulary_file"
 #define GLOBAL_IS_CMIP6               GLOBAL_INTERNAL"cmip6_option"
 
 #define NO_PARENT                     "no parent"
